@@ -285,7 +285,11 @@ handler_dipsaus_progress <- function (
                           progression = progression, ...)
         }
         if (config$clear ) {
-          pb$close(sprintf('%s - Finished\r\n', title))
+          # s <- sprintf('%s - Finished', title)
+          # ss <- paste(rep(' ', stringr::str_length(s)), collapse = '')
+          # cat(sprintf('%s\r%s\n', s, ss))
+          pb$close(sprintf('%s\r', cli::symbol$square_small_filled))
+
         }
       }
     )
